@@ -29,8 +29,6 @@
 #include <QPushButton>
 #include <kurlrequester.h>
 
-#include "ctcron.h"
-#include "cthost.h"
 #include "cttask.h"
 #include "kcm_cron_debug.h"
 
@@ -1137,3 +1135,5 @@ void NumberPushButton::paintEvent(QPaintEvent *)
     }
     p.drawControl(QStyle::CE_PushButton, option);
 }
+
+#include "moc_taskEditorDialog.cpp"
